# Generated by Django 5.0.3 on 2024-06-13 18:36

import django.db.models.deletion
import django.utils.timezone
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("users", "0003_auto_20210219_1548"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AlterField(
            model_name="failedlogin",
            name="failed_on",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="passwordhistory",
            name="password",
            field=models.CharField(max_length=255),
        ),
        migrations.AlterField(
            model_name="passwordhistory",
            name="set_on",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="passwordhistory",
            name="user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                related_name="password_history",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
        migrations.AlterField(
            model_name="recoverytoken",
            name="created_on",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="recoverytoken",
            name="token",
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name="recoverytoken",
            name="user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT, related_name="recovery_tokens", to=settings.AUTH_USER_MODEL
            ),
        ),
    ]
